# Nicotine+

<img src="pynicotine/gtkgui/icons/hicolor/scalable/apps/org.nicotine_plus.Nicotine.svg" align="right" width="128" style="margin: 0 10px">

Nicotine+ is a graphical client for the [Soulseek](https://www.slsknet.org/news/) peer-to-peer network.

Nicotine+ aims to be a pleasant, free and open source (FOSS) alternative to the official Soulseek client, providing additional functionality while keeping current with the Soulseek protocol.

Nicotine+ uses GTK for its graphical user interface, and is written in Python.

Check out the [screenshots](data/screenshots/SCREENSHOTS.md) and [source code](https://github.com/nicotine-plus/nicotine-plus).
<br clear="right">

# Download Nicotine+

The current stable version of Nicotine+ is 3.2.1, released on February 10, 2022. See the [release notes](NEWS.md).

Downloads are available for:

- [GNU/Linux, *BSD and Solaris](doc/DOWNLOADS.md#gnulinux-bsd-solaris)
- [Windows](doc/DOWNLOADS.md#windows)
- [macOS](doc/DOWNLOADS.md#macos)

# Getting Involved

If you feel like contributing to Nicotine+, there are several ways to help:

* Report a problem or suggest improvements by
  * discussing your findings in the [#nicotine+ IRC channel](https://web.libera.chat/?channel=#nicotine+) on [Libera.Chat](https://libera.chat/), or
  * [creating a new issue](https://github.com/nicotine-plus/nicotine-plus/issues) on GitHub.
* Install the latest unstable build and test Nicotine+, see [TESTING.md](doc/TESTING.md).
* Translate Nicotine+ into another language with [Hosted Weblate](https://hosted.weblate.org/engage/nicotine-plus), see [TRANSLATIONS.md](doc/TRANSLATIONS.md).
* Package Nicotine+ for a distribution or operating system, see [PACKAGING.md](doc/PACKAGING.md).
* Implement bug fixes and features, see [DEVELOPING.md](doc/DEVELOPING.md).
  * For a list of tasks, see the [issue tracker](https://github.com/nicotine-plus/nicotine-plus/issues).
  * For documentation on the Soulseek protocol, see [SLSKPROTOCOL.md](doc/SLSKPROTOCOL.md).

# Where did the name Nicotine come from?

> I was in a geeky mood and was browsing [http://www.bash.org](http://www.bash.org)'s QDB.  
I stumbled across this quote:  
>> **\<etc>** so tempting to release a product called 'nicotine' and wait for the patches.  
>> **\<etc>** then i would have a reason to only apply one patch a day. otherwise, i'm going against medical advise.  
>
> So I thought what the hell and bluntly stole etc's idea.  

<p align="right">Hyriand, <i>former Nicotine maintainer</i>, 2003</p>

# Legal and Privacy

- When connecting to the default Soulseek server, you agree to abide by the Soulseek [rules](https://www.slsknet.org/news/node/681) and [terms of service](https://www.slsknet.org/news/node/682).
- Nicotine+ does not collect any user data. Different policies may apply to the default Soulseek server, which is not operated by the Nicotine+ Team.

# License

Nicotine+ is released under the terms of the [GNU Public License v3](https://www.gnu.org/licenses/gpl-3.0-standalone.html) or later. For a list of contributors, see [AUTHORS.md](AUTHORS.md).
